@@ -2,12 +2,12 @@ package Spreadsheet::WriteExcel::Chart;
 
 ###############################################################################
 #
-# Worksheet - A writer class for Excel Charts.
+# Chart - A writer class for Excel Charts.
 #
 #
 # Used in conjunction with Spreadsheet::WriteExcel
 #
-# Copyright 2000-2004, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2005, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -24,7 +24,7 @@ use Spreadsheet::WriteExcel::BIFFwriter;
 use vars qw($VERSION @ISA);
 @ISA = qw(Spreadsheet::WriteExcel::BIFFwriter);
 
-$VERSION = '2.10';
+$VERSION = '2.13';
 
 ###############################################################################
 #
@@ -40,7 +40,7 @@ sub new {
     $self->{_filename}          = $_[0];
     $self->{_name}              = $_[1];
     $self->{_index}             = $_[2];
-    $self->{_name_encoding}     = $_[3];
+    $self->{_encoding}          = $_[3];
     $self->{_activesheet}       = $_[4];
     $self->{_firstsheet}        = $_[5];
 
@@ -64,6 +64,7 @@ sub new {
     $self->{_active_pane}       = 3;
     $self->{_frozen}            = 0;
     $self->{_selected}          = 0;
+    $self->{_hidden}            = 0;
 
     $self->{_paper_size}        = 0x0;
     $self->{_orientation}       = 0x1;
@@ -201,7 +202,8 @@ sub select {
 
     my $self = shift;
 
-    $self->{_selected} = 1;
+    $self->{_hidden}         = 0; # Selected worksheet can't be hidden.
+    $self->{_selected}       = 1;
 }
 
 
@@ -216,11 +218,31 @@ sub activate {
 
     my $self = shift;
 
-    $self->{_selected} = 1;
+    $self->{_hidden}         = 0; # Active worksheet can't be hidden.
+    $self->{_selected}       = 1;
     ${$self->{_activesheet}} = $self->{_index};
 }
 
 
+###############################################################################
+#
+# hide()
+#
+# Hide this worksheet.
+#
+sub hide {
+
+    my $self = shift;
+
+    $self->{_hidden}         = 1;
+
+    # A hidden worksheet shouldn't be active or selected.
+    $self->{_selected}       = 0;
+    ${$self->{_activesheet}} = 0;
+    ${$self->{_firstsheet}}  = 0;
+}
+
+
 ###############################################################################
 #
 # set_first_sheet()
@@ -233,7 +255,8 @@ sub set_first_sheet {
 
     my $self = shift;
 
-    ${$self->{_firstsheet}} = $self->{_index};
+    $self->{_hidden}         = 0; # Active worksheet can't be hidden.
+    ${$self->{_firstsheet}}  = $self->{_index};
 }
 
 
@@ -247,7 +270,7 @@ __END__
 
 =head1 NAME
 
-Worksheet - A writer class for Excel Charts.
+Chart - A writer class for Excel Charts.
 
 =head1 SYNOPSIS
 
@@ -263,7 +286,7 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MM-MMIV, John McNamara.
+ MM-MMV, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
 
